/*
 * Project name:
     Boot_Test (using mikroC RS232-Bootloader on PIC18's)
 * Copyright:
     (c) FOURNET Olivier 16/08/2017
 * Revision History:
     20051120:
       - initial release (for 64K ROM)
         20170805 :
           - adaptation du code initial de Mikroelektronika  une version PIC18F  ROM 96K
         20170806 :
           - simplification du code source
         20170816 :
           - simplification du code source pour tre multi version PIC18F
 * Description:
     This is a serial port Bootloader implementation. All required bootloader
     routines are placed in the Bootloader file, the only thing that is
     user-configurable is the baudrate of the UART communication, which is set
     in the main().
     Once started in PIC, the bootloader waits for a while (approx. 5 seconds)
     to establish UART communication with the MikroBootloader application on the
     PC. If it fails to do so, the bootloader starts the programme already
     loaded in the MCU (initially it is just a NOP). If the communication is
     established, the bootloader receives the hex file from the PC and places it
     where requred (the MikroBootloader application reads out the hex file and
     takes care of the location where hex is to be placed). When hex download
     has finished, the user is notified by the MikroBootloader to reset the MCU,
     and MCU enters the described bootload sequence again.
 * Test configuration:
     MCU:             PIC18F4685
                      http://ww1.microchip.com/downloads/en/DeviceDoc/39761c.pdf
     Oscillator:      HS, 12.0000 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for PIC
                      http://www.mikroe.com/mikroc/pic/
 * NOTES:
     - It's recommended not to alter the start address of the main().
       Otherwise, less space in ROM will be available for the application being bootloaded.
     - RX and TX UART switches should be turned On (board specific).
 */
#include "built_in.h"

#define _SIZE_ROM_96K_
#include "ROM.h"

//-------------- Boootloader main for PIC18's
void main() org START_MAIN_BOOTLOAD_ADRR {

  UART1_Init(9600);                 // Init USART at 9600

  if(UART_Write_Loop('g','r')) {     // Send 'g' for ~5 sec, if 'r'
    Start_Bootload();                 //   received start bootload
  }
  else
  {
   Start_Program();                  //   else start program
  }
}